@@ -46,15 +46,12 @@ class ClientConnection(object):
         self.port = port
         self.sock = sock
         self.attempts = 0
-        self._create_socket()
-
-    def _create_socket(self):
-        if not self.sock:
-            self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.connect()
 
     def connect(self):
         try:
+            if not self.sock:
+                self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.connect((self.host, self.port))
         except socket.error:
             return
@@ -73,7 +70,7 @@ class ClientConnection(object):
                 self.sock = None
                 if self.attempts >= MAX_ATTEMPTS:
                     raise Exception('Max number of retries reached!')
-                self._create_socket()
+                self.connect()
             time.sleep(.01)
 
     def read(self):
@@ -84,6 +81,7 @@ class ClientConnection(object):
 
     def finish(self):
         self.sock.close()
+        self.sock = None
 
 
 class ServerConnection(object):
